---
sidebar_label: Configuration
---

# Configuration interface

Defines options to configure Puppeteer's behavior during installation and runtime.

See individual properties for more information.

#### Signature:

```typescript
export interface Configuration
```

## Properties

| Property                                                               | Modifiers | Type                                                                | Description                                                                                                                                                                                                                                                                | Default                                                                                                                                                                 |
| ---------------------------------------------------------------------- | --------- | ------------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| [browserRevision?](./puppeteer.configuration.browserrevision.md)       |           | string                                                              | <p><i>(Optional)</i> Specifies a certain version of the browser you'd like Puppeteer to use.</p><p>Can be overridden by <code>PUPPETEER_BROWSER_REVISION</code>.</p><p>See [puppeteer.launch](./puppeteer.puppeteernode.launch.md) on how executable path is inferred.</p> | A compatible-revision of the browser.                                                                                                                                   |
| [cacheDirectory?](./puppeteer.configuration.cachedirectory.md)         |           | string                                                              | <p><i>(Optional)</i> Defines the directory to be used by Puppeteer for caching.</p><p>Can be overridden by <code>PUPPETEER_CACHE_DIR</code>.</p>                                                                                                                           | <code>path.join(os.homedir(), '.cache', 'puppeteer')</code>                                                                                                             |
| [defaultProduct?](./puppeteer.configuration.defaultproduct.md)         |           | [Product](./puppeteer.product.md)                                   | <p><i>(Optional)</i> Specifies which browser you'd like Puppeteer to use.</p><p>Can be overridden by <code>PUPPETEER_PRODUCT</code>.</p>                                                                                                                                   | <code>'chrome'</code>                                                                                                                                                   |
| [downloadHost?](./puppeteer.configuration.downloadhost.md)             |           | string                                                              | <p><i>(Optional)</i> Specifies the URL prefix that is used to download Chromium.</p><p>Can be overridden by <code>PUPPETEER_DOWNLOAD_HOST</code>.</p>                                                                                                                      | Either https://storage.googleapis.com or https://archive.mozilla.org/pub/firefox/nightly/latest-mozilla-central, depending on the product.                              |
| [downloadPath?](./puppeteer.configuration.downloadpath.md)             |           | string                                                              | <p><i>(Optional)</i> Specifies the path for the downloads folder.</p><p>Can be overridden by <code>PUPPETEER_DOWNLOAD_PATH</code>.</p>                                                                                                                                     | <code>&lt;cache&gt;/&lt;product&gt;</code> where <code>&lt;cache&gt;</code> is Puppeteer's cache directory and <code>&lt;product&gt;</code> is the name of the browser. |
| [executablePath?](./puppeteer.configuration.executablepath.md)         |           | string                                                              | <p><i>(Optional)</i> Specifies an executable path to be used in [puppeteer.launch](./puppeteer.puppeteernode.launch.md).</p><p>Can be overridden by <code>PUPPETEER_EXECUTABLE_PATH</code>.</p>                                                                            | Auto-computed.                                                                                                                                                          |
| [experiments?](./puppeteer.configuration.experiments.md)               |           | [ExperimentsConfiguration](./puppeteer.experimentsconfiguration.md) | <i>(Optional)</i> Defines experimental options for Puppeteer.                                                                                                                                                                                                              |                                                                                                                                                                         |
| [logLevel?](./puppeteer.configuration.loglevel.md)                     |           | 'silent' \| 'error' \| 'warn'                                       | <p><i>(Optional)</i> Tells Puppeteer to log at the given level.</p><p>At the moment, any option silences logging.</p>                                                                                                                                                      | <code>undefined</code>                                                                                                                                                  |
| [skipDownload?](./puppeteer.configuration.skipdownload.md)             |           | boolean                                                             | <p><i>(Optional)</i> Tells Puppeteer to not download during installation.</p><p>Can be overridden by <code>PUPPETEER_SKIP_DOWNLOAD</code>.</p>                                                                                                                             |                                                                                                                                                                         |
| [temporaryDirectory?](./puppeteer.configuration.temporarydirectory.md) |           | string                                                              | <p><i>(Optional)</i> Defines the directory to be used by Puppeteer for creating temporary files.</p><p>Can be overridden by <code>PUPPETEER_TMP_DIR</code>.</p>                                                                                                            | <code>os.tmpdir()</code>                                                                                                                                                |
